# fastchem presets data

## logK data

logK data were taken  from [FastChem](https://github.com/NewStrangeWorlds/FastChem) v3.1.3 in September 30 (2025),  which is distributed under the GNU General Public License v3 (GPLv3). Accordingly, ExoGibbs is also distributed under the GPLv3 license.

